@@ -6,19 +6,12 @@ import grblas as gb
 
 from .. import ffi, lib, monoid
 from ..base import call
-from ..dtypes import INT64, lookup_dtype
+from ..dtypes import _INDEX, INT64, UINT64, lookup_dtype
 from ..exceptions import check_status, check_status_carg
-from ..scalar import _CScalar
-from ..utils import (
-    _CArray,
-    ints_to_numpy_buffer,
-    libget,
-    values_to_numpy_buffer,
-    wrapdoc,
-)
+from ..scalar import _as_scalar
+from ..utils import _CArray, ints_to_numpy_buffer, libget, values_to_numpy_buffer, wrapdoc
 from .matrix import MatrixArray, _concat_mn, normalize_chunks
 from .prefix_scan import prefix_scan
-from .scalar import gxb_scalar
 from .utils import get_order
 
 ffi_new = ffi.new
@@ -147,7 +140,7 @@ class ss:
             # Transpose descriptor doesn't do anything, so use the parent
             k = -k
             matrix = matrix._matrix
-        call("GxB_Vector_diag", [self._parent, matrix, _CScalar(k, INT64), None])
+        call("GxB_Vector_diag", [self._parent, matrix, _as_scalar(k, INT64, is_cscalar=True), None])
 
     def split(self, chunks, *, name=None):
         """
@@ -180,8 +173,8 @@ class ss:
             "GxB_Matrix_split",
             [
                 MatrixArray(tiles, parent, name="tiles"),
-                _CScalar(m),
-                _CScalar(1),
+                _as_scalar(m, _INDEX, is_cscalar=True),
+                _as_scalar(1, _INDEX, is_cscalar=True),
                 _CArray(tile_nrows),
                 _CArray([1]),
                 parent,
@@ -210,8 +203,8 @@ class ss:
             [
                 self._parent._as_matrix(),
                 MatrixArray(ctiles, name="tiles"),
-                _CScalar(m),
-                _CScalar(1),
+                _as_scalar(m, _INDEX, is_cscalar=True),
+                _as_scalar(1, _INDEX, is_cscalar=True),
                 None,
             ],
         )
@@ -246,11 +239,16 @@ class ss:
         Vector.from_values
         """
         indices = ints_to_numpy_buffer(indices, np.uint64, name="indices")
-        scalar = gxb_scalar(self._parent.dtype, value)
-        status = lib.GxB_Vector_build_Scalar(
-            self._parent._carg, _CArray(indices)._carg, scalar[0], indices.size
+        scalar = _as_scalar(value, self._parent.dtype, is_cscalar=False)  # pragma: is_grbscalar
+        call(
+            "GxB_Vector_build_Scalar",
+            [
+                self._parent,
+                _CArray(indices),
+                scalar,
+                _as_scalar(indices.size, _INDEX, is_cscalar=True),
+            ],
         )
-        check_status(status, self._parent)
 
     def export(self, format=None, *, sort=False, give_ownership=False, raw=False):
         """
@@ -1232,7 +1230,7 @@ class ss:
         else:
             raise NotImplementedError(fmt)
 
-    def selectk(self, how, k):
+    def selectk(self, how, k, *, name=None):
         """Select (up to) k elements.
 
         Parameters
@@ -1277,6 +1275,114 @@ class ss:
         return gb.Vector.ss.import_sparse(
             **newinfo,
             take_ownership=True,
+            name=name,
+        )
+
+    def compactify(self, how="first", size=None, *, reverse=False, asindex=False, name=None):
+        """Shift all values to the beginning so all values are contiguous.
+
+        This returns a new Vector.
+
+        Parameters
+        ----------
+        how : {"first", "last", "smallest", "largest", "random"}, optional
+            How to compress the values:
+            - first : take the values nearest the beginning
+            - last : take the values nearest the end
+            - smallest : take the smallest values (if tied, may take any)
+            - largest : take the largest values (if tied, may take any)
+            - random : take values randomly with equal probability and without replacement
+        reverse : bool, default False
+            Reverse the values when True
+        asindex : bool, default False
+            Return the index of the value when True.  If there are ties for
+            "smallest" and "largest", then any valid index may be returned.
+        size : int, optional
+            The size of the returned Vector.  If not specified, then the Vector
+            will be "compacted" to the smallest size that doesn't lose values.
+
+        **THIS API IS EXPERIMENTAL AND MAY CHANGE**
+
+        """
+        how = how.lower()
+        if how not in {"first", "last", "smallest", "largest", "random"}:
+            raise ValueError(
+                '`how` argument must be one of: "first", "last", "smallest", "largest", "random"'
+            )
+        if size is None and self._parent._nvals == 0 or size == 0:
+            if asindex:
+                return gb.Vector.new(UINT64, size=0, name=name)
+            else:
+                return gb.Vector.new(self._parent.dtype, size=0, name=name)
+        do_sort = how in {"first", "last"}
+        info = self._parent.ss.export("sparse", sort=do_sort)
+        if size is None:
+            size = info["indices"].size
+        if info["is_iso"]:
+            if how in {"smallest", "largest"} or how == "random" and not asindex:
+                # order of smallest/largest/random doesn't matter
+                how = "first"
+                reverse = False
+            if not asindex:
+                how = "finished"
+                reverse = False
+            else:
+                info["is_iso"] = False
+
+        if how == "random":
+            choices = random_choice(self._parent._nvals, size)
+        elif how == "first":
+            if reverse:
+                choices = slice(size - 1, None, -1)
+                reverse = False
+            else:
+                choices = slice(None, size)
+        elif how == "last":
+            if reverse:
+                choices = slice(-size, None)
+                reverse = False
+            else:
+                choices = slice(None, -size - 1, -1)
+        elif how in {"largest", "smallest"}:
+            values = info["values"]
+            if how == "largest":
+                slc = slice(-size, None)
+                stop = -size
+                reverse = not reverse
+            else:
+                slc = slice(size)
+                stop = size
+            if asindex:
+                if size < values.size:
+                    idx = np.argpartition(values, stop)[slc]
+                    choices = idx[np.argsort(values[idx])]
+                else:
+                    choices = np.argsort(values)
+                values = info["indices"][choices]
+            else:
+                if size < values.size:
+                    values = np.partition(values, stop)[slc]
+                values.sort()
+        else:
+            choices = slice(None)
+        if how not in {"largest", "smallest"}:
+            if asindex:
+                values = info["indices"][choices]
+            else:
+                values = info["values"][choices]
+        if reverse:
+            values = values[::-1]
+        newinfo = dict(
+            info,
+            values=values,
+            indices=np.arange(size, dtype=np.uint64),
+            sorted_index=True,
+            size=size,
+        )
+        return gb.Vector.ss.import_sparse(
+            **newinfo,
+            take_ownership=True,
+            name=name,
         )
 
 
