@@ -109,10 +109,11 @@ def _update_matrix_dataframe(df, matrix, rows, row_offset, columns, column_offse
         if type(matrix) is TransposedMatrix:
             parent = matrix._matrix
             submatrix = Matrix.new(parent.dtype, parent._nrows, parent._ncols, name="")
-            # Get val to support iso-valued matrices
-            val = parent.reduce_scalar(monoid.any).new(name="")
-            submatrix(parent.S)[columns, rows] = val
-            submatrix(submatrix.S)[...] = parent
+            if parent._nvals > 0:
+                # Get val to support iso-valued matrices
+                val = parent.reduce_scalar(monoid.any, allow_empty=False).new(name="")
+                submatrix(parent.S)[columns, rows] = val
+                submatrix(submatrix.S)[...] = parent
             if row_offset is not None or column_offset is not None:
                 submatrix = submatrix[column_offset:, row_offset:].new(name="")
             submatrix = submatrix.T
@@ -120,9 +121,10 @@ def _update_matrix_dataframe(df, matrix, rows, row_offset, columns, column_offse
             if mask is None:
                 submatrix = Matrix.new(matrix.dtype, matrix._nrows, matrix._ncols, name="")
                 # Get val to support iso-valued matrices
-                val = matrix.reduce_scalar(monoid.any).new(name="")
-                submatrix(matrix.S)[rows, columns] = val
-                submatrix(submatrix.S)[...] = matrix
+                if matrix._nvals > 0:
+                    val = matrix.reduce_scalar(monoid.any).new(name="")
+                    submatrix(matrix.S)[rows, columns] = val
+                    submatrix(submatrix.S)[...] = matrix
             else:
                 submatrix = Matrix.new("UINT8", matrix._nrows, matrix._ncols, name="")
                 if mask.structure:
@@ -153,9 +155,10 @@ def _update_vector_dataframe(df, vector, columns, column_offset, *, mask=None):
         if mask is None:
             subvector = Vector.new(vector.dtype, vector._size, name="")
             # Get val to support iso-valued vectors
-            val = vector.reduce(monoid.any).new(name="")
-            subvector(vector.S)[columns] = val
-            subvector(subvector.S)[...] = vector
+            if vector._nvals > 0:
+                val = vector.reduce(monoid.any).new(name="")
+                subvector(vector.S)[columns] = val
+                subvector(subvector.S)[...] = vector
         else:
             subvector = Vector.new("UINT8", vector._size, name="")
             if mask.structure:
@@ -236,7 +239,7 @@ def _get_matrix_dataframe(matrix, max_rows, min_rows, max_columns, *, mask=None)
                 vals = np.ones(vals.size, dtype=np.uint8)
         df = pd.DataFrame({"row": rows, "col": cols, "val": vals})
         if num_rows < matrix._nvals:
-            df = df.append(pd.Series(["..."] * 3, index=df.columns, name="..."))
+            df.loc["..."] = ["..."] * 3
         return df
     if mask is not None and not mask.structure and df.shape != matrix.shape:
         # This performs more calculation and uses more memory than I would prefer.
@@ -251,7 +254,7 @@ def _get_matrix_dataframe(matrix, max_rows, min_rows, max_columns, *, mask=None)
                 vals[:] = 0
             df = pd.DataFrame({"row": rows, "col": cols, "val": vals})
             if num_rows < nonzero._nvals:
-                df = df.append(pd.Series(["..."] * 3, index=df.columns, name="..."))
+                df.loc["..."] = ["..."] * 3
             return df
     return df.where(pd.notnull(df), "")
 
@@ -286,7 +289,7 @@ def _get_vector_dataframe(vector, max_rows, min_rows, max_columns, *, mask=None)
                 vals = np.ones(vals.size, dtype=np.uint8)
         df = pd.DataFrame({"index": indices, "val": vals})
         if num_rows < vector._nvals:
-            df = df.append(pd.Series(["..."] * 2, index=df.columns, name="..."))
+            df.loc["..."] = ["..."] * 2
         return df
     if mask is not None and not mask.structure and df.size != vector._size:
         # This performs more calculation and uses more memory than I would prefer.
@@ -301,7 +304,7 @@ def _get_vector_dataframe(vector, max_rows, min_rows, max_columns, *, mask=None)
                 vals[:] = 0
             df = pd.DataFrame({"index": indices, "val": vals})
             if num_rows < nonzero._nvals:
-                df = df.append(pd.Series(["..."] * 2, index=df.columns, name="..."))
+                df.loc["..."] = ["..."] * 2
             return df
     return df.where(pd.notnull(df), "")
 
@@ -734,3 +737,78 @@ def format_matrix_infix_expression_html(expr):
         [expr._nrows, expr._ncols, expr.left.dtype, expr.right.dtype],
     )
     return _format_infix_expression(expr, header, expr_html)
+
+
+def format_index_expression(expr):
+    name = f"grblas.{type(expr).__name__}"
+    indices = ", ".join(index._expr_name for index in expr.resolved_indexes.indices)
+    expr_repr = f"{expr.parent.name}[{indices}]"
+    keys = []
+    values = []
+    if expr.output_type is Vector:
+        keys.append("size")
+        values.append(expr._size)
+    elif expr.output_type is Matrix:
+        keys.extend(["nrows", "ncols"])
+        values.extend([expr._nrows, expr._ncols])
+    keys.append("dtype")
+    values.append(expr.dtype)
+    header = create_header(
+        expr_repr,
+        keys,
+        values,
+        name=name,
+        quote=False,
+    )
+    arg_string = get_result_string(expr)
+    c = expr.output_type.__name__[0]
+    return (
+        f"{header}\n\n"
+        f"{arg_string}"
+        f"This expression may be used to extract or assign a {expr.output_type.__name__}.\n"
+        f"Example extract: {expr_repr}.new()\n"
+        f"Example assign: {expr_repr} << {'M' if c == 'M' else c.lower()}"
+    )
+
+
+def format_index_expression_html(expr):
+    indices = ", ".join(index._expr_name for index in expr.resolved_indexes.indices)
+    expr_repr = f"{expr.parent._name_html}[{indices}]"
+    keys = []
+    values = []
+    if expr.output_type is Vector:
+        keys.append("size")
+        values.append(expr._size)
+    elif expr.output_type is Matrix:
+        keys.extend(["nrows", "ncols"])
+        values.extend([expr._nrows, expr._ncols])
+    keys.append("dtype")
+    values.append(expr.dtype)
+    header = create_header_html(
+        expr_repr,
+        keys,
+        values,
+    )
+    arg_string = expr.parent._repr_html_(collapse=True)
+    if config.get("autocompute"):
+        arg_string += get_expr_result(expr, html=True)
+    c = expr.output_type.__name__[0]
+    c = "M" if c == "M" else c.lower()
+    return (
+        "<div>"
+        '<details class="gb-expr-details">'
+        '<summary class="gb-expr-summary">'
+        f"<b><tt>grblas.{type(expr).__name__}:</tt></b>"
+        f"{header}"
+        "</summary>"
+        '<blockquote class="gb-expr-blockquote">'
+        f"{arg_string}"
+        "</blockquote>"
+        "</details>"
+        "<em>"
+        f"This expression may be used to extract or assign a <tt>{expr.output_type.__name__}</tt>."
+        f"<br>Example extract: <code>{expr_repr}.new()</code>"
+        f"<br>Example assign: <code>{expr_repr} << {'M' if c == 'M' else c.lower()}</code>"
+        "</em>"
+        "</div>"
+    )
