@@ -614,7 +614,7 @@ class OpBase:
         ):
             if re_str not in cls._parse_config:
                 continue
-            if "complex" in re_str and not _supports_complex:  # pragma: no cover
+            if "complex" in re_str and not _supports_complex:
                 continue
             for r in reversed(cls._parse_config[re_str]):
                 for varname in _VARNAMES:
@@ -862,7 +862,9 @@ class UnaryOp(OpBase):
                     typed_op = op._typed_ops[target_type]
                     output_type = op.types[target_type]
                     for dtype in input_types:
-                        if dtype not in op.types:
+                        if dtype not in op.types and (
+                            _supports_complex or dtype not in {"FC32", "FC64"}
+                        ):
                             op.types[dtype] = output_type
                             op._typed_ops[dtype] = typed_op
                             op.coercions[dtype] = target_type
@@ -1219,7 +1221,7 @@ class BinaryOp(OpBase):
             ),
             # fmt: on
         ]
-        if _supports_complex:  # pragma: no branch
+        if _supports_complex:
             name_types.append(
                 (
                     ["cmplx"],
@@ -1234,7 +1236,9 @@ class BinaryOp(OpBase):
                     typed_op = cur_op._typed_ops[target_type]
                     output_type = cur_op.types[target_type]
                     for dtype in input_types:
-                        if dtype not in cur_op.types:  # pragma: no branch
+                        if dtype not in cur_op.types and (
+                            _supports_complex or dtype not in {"FC32", "FC64"}
+                        ):
                             cur_op.types[dtype] = output_type
                             cur_op._typed_ops[dtype] = typed_op
                             cur_op.coercions[dtype] = target_type
@@ -1662,7 +1666,9 @@ class Semiring(OpBase):
                     typed_op = cur_op._typed_ops[target_type]
                     output_type = cur_op.types[target_type]
                     for dtype in input_types:
-                        if dtype not in cur_op.types:
+                        if dtype not in cur_op.types and (
+                            _supports_complex or dtype not in {"FC32", "FC64"}
+                        ):
                             cur_op.types[dtype] = output_type
                             cur_op._typed_ops[dtype] = typed_op
                             cur_op.coercions[dtype] = target_type
@@ -1757,10 +1763,20 @@ def get_typed_op(op, dtype, dtype2=None, *, is_left_scalar=False, is_right_scala
             op = monoid_from_string(op)
         elif kind == "semiring":
             op = semiring_from_string(op)
+        elif kind == "binary|aggregator":
+            try:
+                op = binary_from_string(op)
+            except ValueError:
+                try:
+                    op = aggregator_from_string(op)
+                except ValueError:
+                    raise ValueError(
+                        f"Unknown binary or aggregator string: {op!r}.  Example usage: '+[int]'"
+                    ) from None
         else:
             raise ValueError(
                 f"Unable to get op from string {op!r}.  `kind=` argument must be provided as "
-                '"unary", "binary", "monoid", or "semiring".'
+                '"unary", "binary", "monoid", "semiring", or "binary|aggregator".'
             )
         return get_typed_op(
             op,
@@ -1956,7 +1972,7 @@ def _from_string(string, module, mapping, example):
             op = mapping[base] = module.from_string(op)
     elif hasattr(module, base):
         op = getattr(module, base)
-    elif hasattr(module.numpy, base):
+    elif hasattr(module, "numpy") and hasattr(module.numpy, base):
         op = getattr(module.numpy, base)
     else:
         *paths, attr = base.split(".")
@@ -2026,4 +2042,19 @@ monoid.from_string = monoid_from_string
 semiring.from_string = semiring_from_string
 op.from_string = op_from_string
 
+from . import agg  # noqa isort:skip
 from .agg import Aggregator, TypedAggregator  # noqa isort:skip
+
+_str_to_agg = {
+    "+": agg.sum,
+    "*": agg.prod,
+    "&": agg.all,
+    "|": agg.any,
+}
+
+
+def aggregator_from_string(string):
+    return _from_string(string, agg, _str_to_agg, "sum[int]")
+
+
+agg.from_string = aggregator_from_string
