@@ -1,3 +1,4 @@
+import numpy as np
 import pytest
 
 from grblas import binary, dtypes, replace, unary
@@ -149,16 +150,16 @@ def test_updater_only_once():
         u[[0, 1]]()[0]
     with pytest.raises(TypeError, match="is not subscriptable"):
         u()[[0, 1]][0]
-    with pytest.raises(TypeError, match="is not subscriptable"):
+    with pytest.raises(TypeError, match="autocompute"):
         u[[0, 1]][0]
 
 
 def test_bad_extract_with_updater():
     u = Vector.from_values([0, 1, 3], [1, 2, 3])
-    assert u[0].value == 1
+    assert u[0].new() == 1
     with pytest.raises(AttributeError, match="'Assigner' object has no attribute 'value'"):
         u(mask=u.S)[0].value
-    with pytest.raises(AttributeError, match="Only Scalars"):
+    with pytest.raises(AttributeError, match="has no attribute"):
         u[[0, 1]].value
     with pytest.raises(AttributeError, match="'Assigner' object has no attribute 'new'"):
         u(mask=u.S)[0].new()
@@ -166,7 +167,7 @@ def test_bad_extract_with_updater():
         u << u(mask=u.S)[[1, 2]]
     with pytest.raises(TypeError, match="Assignment value must be a valid expression"):
         u << u()[[1, 2]]
-    with pytest.raises(TypeError, match="mask is not allowed for single element extraction"):
+    with pytest.raises(TypeError, match="unexpected keyword argument"):
         u[0].new(mask=u.S)
     s = Scalar.from_value(10)
     with pytest.raises(TypeError, match="Indexing not supported for Scalars"):
@@ -185,3 +186,63 @@ def test_updater_on_rhs():
         u << u()
     with pytest.raises(TypeError, match="Bad type for argument `value`"):
         u[:] << u()
+
+
+def test_py_indices():
+    v = Vector.from_values(np.arange(5), np.arange(5))
+
+    idx = v[:].resolved_indexes.py_indices
+    assert idx == slice(None)
+    w = v[idx].new()
+    assert w.isequal(v)
+
+    idx = v[3].resolved_indexes.py_indices
+    assert idx == 3
+
+    idx = v[[0, 2]].resolved_indexes.py_indices
+    np.testing.assert_array_equal(idx, [0, 2])
+
+    idx = v[0:0].resolved_indexes.py_indices
+    assert idx == slice(1, 1)  # strange, but expected
+    w = v[idx].new()
+    assert w.size == 0
+
+    idx = v[2:0].resolved_indexes.py_indices
+    assert idx == slice(2, 1)  # strange, but expected
+    w = v[idx].new()
+    assert w.size == 0
+
+    idx = v[::-1].resolved_indexes.py_indices
+    assert idx == slice(None, None, -1)
+    w = v[idx].new()
+    expected = Vector.from_values(np.arange(5), np.arange(5)[::-1])
+    assert w.isequal(expected)
+
+    idx = v[4:-3:-1].resolved_indexes.py_indices
+    assert idx == slice(None, -v.size - 1 + 3, -1)
+    w = v[idx].new()
+    expected = Vector.from_values(np.arange(2), np.arange(5)[4:-3:-1])
+    assert w.isequal(expected)
+
+    idx = v[1::2].resolved_indexes.py_indices
+    assert idx == slice(1, None, 2)
+    w = v[idx].new()
+    expected = Vector.from_values(np.arange(2), np.arange(5)[1::2])
+    assert w.isequal(expected)
+
+    A = Matrix.from_values([0, 1, 2], [2, 0, 1], [0, 2, 3], nrows=10, ncols=10)
+    idx = A[1:6, 8:-8:-2].resolved_indexes.py_indices
+    assert idx == (slice(1, 6), slice(8, -8, -2))
+
+    # start=0 -> None
+    idx = v[0:2].resolved_indexes.py_indices
+    assert idx == slice(None, 2)
+    # stop=size -> None
+    idx = v[1 : v.size].resolved_indexes.py_indices
+    assert idx == slice(1, None)
+    # step=1 -> None
+    idx = v[1:3:1].resolved_indexes.py_indices
+    assert idx == slice(1, 3)
+    # All together now!
+    idx = v[0 : v.size : 1].resolved_indexes.py_indices
+    assert idx == slice(None)
